from setuptools import setup

setup(name='distributions_something_interesting',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions_something_interesting'],
      author='Carl Shi',
      zip_safe=False)
